@@ -1,7 +1,7 @@
 try:
     from importlib.metadata import version
     __version__ = version("c2pa-python")
-except ImportError:
+except ImportError:  # pragma: no cover
     __version__ = "unknown"
 
 from .c2pa import (
